@@ -64,6 +64,7 @@ GtkWidget *CddbSetToFileName;
 
 GtkWidget *CddbRunScanner;
 GtkWidget *CddbUseDLM2; // '2' as also used in the prefs.c
+GtkWidget *CddbUseLocalAccess;
 
 
 
@@ -73,9 +74,9 @@ GtkWidget *CddbUseDLM2; // '2' as also used in the prefs.c
 typedef struct _CddbAlbum CddbAlbum;
 struct _CddbAlbum
 {
-    gchar *server_name;     /* Param of server name used for the connection */
-    gint   server_port;     /* Param of server port used for the connection */
-    gchar *server_cgi_path; /* Param of server cgi path used for the connection */
+    gchar *server_name;     /* Remote access : Param of server name used for the connection     - Local access : NULL */
+    gint   server_port;     /* Remote access : Param of server port used for the connection     - Local access : 0 */
+    gchar *server_cgi_path; /* Remote access : Param of server cgi path used for the connection - Local access : discid file path */
 
     gchar *artist_album;    /* CDDB artist+album (allocated) */
     gchar *category;        /* CDDB genre (allocated) */
@@ -83,7 +84,7 @@ struct _CddbAlbum
     GList *track_list;      /* List of tracks name of the album (list of CddbTrackAlbum items) */
     gboolean other_version; /* To TRUE if this album is an other version of the previous one */
 
-    // We get these data with the track list
+    // We fill these data when loading the track list
     gchar *artist;    /* (allocated) */
     gchar *album;     /* (allocated) */
     gchar *genre;     /* (allocated) */
