@@ -32,11 +32,14 @@
 #include <string.h>
 #include <ctype.h>
 #include <unistd.h>
+#include <string.h>
+#include <stdlib.h>
 
 #include "mp4_tag.h"
 #include "picture.h"
 #include "easytag.h"
 #include "setting.h"
+#include "log.h"
 #include "misc.h"
 #include "et_core.h"
 #include "charset.h"
@@ -88,7 +91,7 @@ gboolean Mp4tag_Read_File_Tag (gchar *filename, File_Tag *FileTag)
     if ( (file=fopen(filename,"r"))==NULL )
     {
         gchar *filename_utf8 = filename_to_display(filename);
-        g_print(_("ERROR while opening file: '%s' (%s).\n\a"),filename_utf8,g_strerror(errno));
+        Log_Print(_("ERROR while opening file: '%s' (%s).\a"),filename_utf8,g_strerror(errno));
         g_free(filename_utf8);
         return FALSE;
     }
@@ -99,7 +102,7 @@ gboolean Mp4tag_Read_File_Tag (gchar *filename, File_Tag *FileTag)
     if (mp4file == MP4_INVALID_FILE_HANDLE)
     {
         gchar *filename_utf8 = filename_to_display(filename);
-        g_print(_("ERROR while opening file: '%s' (%s).\n\a"),filename_utf8,_("MP4 format invalid"));
+        Log_Print(_("ERROR while opening file: '%s' (%s).\a"),filename_utf8,_("MP4 format invalid"));
         g_free(filename_utf8);
         return FALSE;
     }
@@ -213,6 +216,7 @@ gboolean Mp4tag_Write_File_Tag (ET_File *ETFile)
 {
     File_Tag *FileTag;
     gchar    *filename;
+    gchar    *filename_utf8;
     FILE     *file;
     MP4FileHandle mp4file = NULL;
     gint error = 0;
@@ -221,14 +225,13 @@ gboolean Mp4tag_Write_File_Tag (ET_File *ETFile)
         return FALSE;
 
     FileTag = (File_Tag *)ETFile->FileTag->data;
-    filename = ((File_Name *)ETFile->FileNameCur->data)->value;
+    filename      = ((File_Name *)ETFile->FileNameCur->data)->value;
+    filename_utf8 = ((File_Name *)ETFile->FileNameCur->data)->value_utf8;
 
     /* Test to know if we can write into the file */
     if ( (file=fopen(filename,"r+"))==NULL )
     {
-        gchar *filename_utf8 = filename_to_display(filename);
-        g_print(_("ERROR while opening file: '%s' (%s).\n\a"),filename_utf8,g_strerror(errno));
-        g_free(filename_utf8);
+        Log_Print(_("ERROR while opening file: '%s' (%s).\a"),filename_utf8,g_strerror(errno));
         return FALSE;
     }
     fclose(file);
@@ -237,9 +240,7 @@ gboolean Mp4tag_Write_File_Tag (ET_File *ETFile)
     mp4file = MP4Modify(filename,0,0);
     if (mp4file == MP4_INVALID_FILE_HANDLE)
     {
-        gchar *filename_utf8 = filename_to_display(filename);
-        g_print(_("ERROR while opening file: '%s' (%s).\n\a"),filename_utf8,_("MP4 format invalid"));
-        g_free(filename_utf8);
+        Log_Print(_("ERROR while opening file: '%s' (%s).\a"),filename_utf8,_("MP4 format invalid"));
         return FALSE;
     }
 
