@@ -34,6 +34,7 @@
 
 #include "picture.h"
 #include "easytag.h"
+#include "log.h"
 #include "misc.h"
 #include "setting.h"
 #include "msgbox.h"
@@ -41,7 +42,7 @@
 #include "charset.h"
 
 #ifdef WIN32
-#   include "win32dep.h"
+#   include "win32/win32dep.h"
 #endif
 
 
@@ -173,13 +174,17 @@ void Picture_Clear_Button_Clicked (GObject *object)
     {
         GtkTreePath *path = gtk_tree_row_reference_get_path(node->data);
         Picture *pic;
+        gboolean valid;
 
-        gtk_tree_model_get_iter(model, &iter, path);
+        valid = gtk_tree_model_get_iter(model, &iter, path);
+        if (valid)
+        {
+            gtk_tree_model_get(model, &iter, PICTURE_COLUMN_DATA, &pic,-1);
+            Picture_Free(pic);
 
-        gtk_tree_model_get(model, &iter, PICTURE_COLUMN_DATA, &pic,-1);
-        Picture_Free(pic);
+            gtk_list_store_remove(GTK_LIST_STORE(model), &iter);
+        }
 
-        gtk_list_store_remove(GTK_LIST_STORE(model), &iter);
         gtk_tree_row_reference_deleted(proxy, path);
         gtk_tree_path_free(path);
         gtk_tree_row_reference_free(node->data);
@@ -321,6 +326,7 @@ void Picture_Add_Button_Clicked (GObject *object)
     {
         case MP4_TAG:
         {
+            // Only one file can be selected
             gtk_file_chooser_set_select_multiple(GTK_FILE_CHOOSER(FileSelectionWindow), FALSE);
             break;
         }
@@ -334,6 +340,15 @@ void Picture_Add_Button_Clicked (GObject *object)
     }
 
     gtk_dialog_set_default_response(GTK_DIALOG(FileSelectionWindow), GTK_RESPONSE_OK);
+
+    // Starting directory (the same of the current file)
+    if (ETCore->ETFileDisplayed)
+    {
+        gchar *cur_filename_utf8 = ((File_Name *)((GList *)ETCore->ETFileDisplayed->FileNameCur)->data)->value_utf8;
+        init_dir = g_path_get_dirname(cur_filename_utf8);
+        gtk_file_chooser_set_current_folder(GTK_FILE_CHOOSER(FileSelectionWindow),init_dir);
+    }else
+    // Starting directory (the same than the previous one)
     if (init_dir)
         gtk_file_chooser_set_current_folder(GTK_FILE_CHOOSER(FileSelectionWindow),init_dir);
 
@@ -413,14 +428,16 @@ void Picture_Properties_Button_Clicked (GObject *object)
     while (selection_list)
     {
         GtkTreePath *path = selection_list->data;
-        Picture *pic;
+        Picture *pic = NULL;
         GtkTreeSelection *selectiontype;
         gchar *title;
         GtkTreePath *rowPath;
+        gboolean valid;
 
         // Get corresponding picture
-        gtk_tree_model_get_iter(GTK_TREE_MODEL(model), &iter, path);
-        gtk_tree_model_get(GTK_TREE_MODEL(model), &iter, PICTURE_COLUMN_DATA, &pic, -1);
+        valid = gtk_tree_model_get_iter(GTK_TREE_MODEL(model), &iter, path);
+        if (valid)
+            gtk_tree_model_get(GTK_TREE_MODEL(model), &iter, PICTURE_COLUMN_DATA, &pic, -1);
 
         title = g_strdup_printf(_("Picture Properties %d/%d"),selection_i++,selection_nbr);
         PictureTypesWindow = gtk_dialog_new_with_buttons(title,
@@ -619,10 +636,12 @@ void Picture_Save_Button_Clicked (GObject *object)
         GtkTreeIter iter;
         Picture *pic;
         gchar *title;
+        gboolean valid;
 
         // Get corresponding picture
-        gtk_tree_model_get_iter(GTK_TREE_MODEL(model), &iter, path);
-        gtk_tree_model_get(GTK_TREE_MODEL(model), &iter, PICTURE_COLUMN_DATA, &pic, -1);
+        valid = gtk_tree_model_get_iter(GTK_TREE_MODEL(model), &iter, path);
+        if (valid)
+            gtk_tree_model_get(GTK_TREE_MODEL(model), &iter, PICTURE_COLUMN_DATA, &pic, -1);
 
         title = g_strdup_printf(_("Save picture %d/%d"),selection_i++,selection_nbr);
         FileSelectionWindow = gtk_file_chooser_dialog_new(title,
@@ -960,7 +979,7 @@ void PictureEntry_Update (Picture *pic, gint select)
 
                 msg = g_strdup(_("Can't display the picture, as not enough data "
                     "has been read to determine how to create the image buffer."));
-                g_print("%s\n",msg);
+                Log_Print("%s",msg);
                 msgbox = msg_box_new(_("Loading Picture File..."),msg,
                     GTK_STOCK_DIALOG_ERROR,BUTTON_YES,0);
                 msg_box_hide_check_button(MSG_BOX(msgbox));
@@ -1075,7 +1094,7 @@ Picture *Picture_Load_File_Data (const gchar *filename)
 
     pic = Picture_Allocate();
     pic->size = size;
-    pic->data = buffer;
+    pic->data = (guchar *)buffer;
     return pic;
 
     fail:
