@@ -43,7 +43,7 @@
 #include "charset.h"
 
 //#ifdef WIN32
-//#   include "win32dep.h"
+//#   include "win32/win32dep.h"
 //#endif
 
 
@@ -67,7 +67,8 @@ void Use_Non_Standard_Id3_Writing_Character_Set_Toggled (void);
 void Scanner_Convert_Check_Button_Toggled_1    (GtkObject *object_rec, GtkObject *object_emi);
 void Cddb_Use_Proxy_Toggled                    (void);
 
-void DefaultPathToMp3_Combo_Add_String (void);
+void DefaultPathToMp3_Combo_Add_String             (void);
+void CddbLocalPath_Combo_Add_String (void);
 
 
 
@@ -175,18 +176,18 @@ void Open_OptionsWindow (void)
         "(directories starting by a '.')."),NULL);
 
     /* Load directory on startup */
+    HBox = gtk_hbox_new(FALSE,2);
+    gtk_box_pack_start(GTK_BOX(vbox),HBox,FALSE,FALSE,0);
+    //gtk_container_set_border_width(GTK_CONTAINER(HBox), 2);
+
     // Check box
     LoadOnStartup = gtk_check_button_new_with_label(_("Load on startup the directory"));
-    gtk_box_pack_start(GTK_BOX(vbox),LoadOnStartup,FALSE,FALSE,0);
+    gtk_box_pack_start(GTK_BOX(HBox),LoadOnStartup,FALSE,FALSE,0);
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(LoadOnStartup),LOAD_ON_STARTUP);
     gtk_tooltips_set_tip(Tips,LoadOnStartup,_("Automatically search files, when EasyTAG starts, "
         "into the following directory. Note that this path may be overriden by the parameter "
         "passed to easytag (easytag /path_to/mp3_files)."),NULL);
 
-    HBox = gtk_hbox_new(FALSE,4);
-    gtk_box_pack_start(GTK_BOX(vbox),HBox,FALSE,FALSE,2);
-    gtk_container_set_border_width(GTK_CONTAINER(HBox), 2);
-
     // Combo
     if (DefaultPathModel != NULL)
         gtk_list_store_clear(DefaultPathModel);
@@ -317,7 +318,7 @@ void Open_OptionsWindow (void)
         "when loading a directory."),NULL);
 
     SortingFileCaseSensitive = gtk_check_button_new_with_label(_("Case sensitive"));
-#ifndef WIN32 /* Always true and not user modifiable on win32, as strncasecmp() don't work correctly with g_utf8_collate_key() */
+#ifndef WIN32 /* Always true and not user modifiable on win32, as strncasecmp() doesn't work correctly with g_utf8_collate_key() */
     gtk_box_pack_start(GTK_BOX(hbox),SortingFileCaseSensitive,FALSE,FALSE,0);
 #endif
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(SortingFileCaseSensitive),
@@ -328,12 +329,14 @@ void Open_OptionsWindow (void)
     /* Message Dialog Position */
     Frame = gtk_frame_new (_("Message Dialog Position"));
     gtk_box_pack_start(GTK_BOX(VBox),Frame,FALSE,FALSE,0);
-    vbox = gtk_vbox_new(TRUE,4);
-    gtk_container_add(GTK_CONTAINER(Frame),vbox);
-    gtk_container_set_border_width(GTK_CONTAINER(vbox), 4);
+    Table = gtk_table_new(2,2,FALSE);
+    gtk_container_add(GTK_CONTAINER(Frame),Table);
+    //gtk_table_set_row_spacings(GTK_TABLE(Table),2);
+    gtk_table_set_col_spacings(GTK_TABLE(Table),4);
+
 
     MessageBoxPositionNone = gtk_radio_button_new_with_label(NULL,_("No particular position"));
-    gtk_box_pack_start(GTK_BOX(vbox),MessageBoxPositionNone,FALSE,FALSE,0);
+    gtk_table_attach(GTK_TABLE(Table),MessageBoxPositionNone,0,1,0,1,GTK_FILL,GTK_FILL,0,0);
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(MessageBoxPositionNone),
         MESSAGE_BOX_POSITION_NONE);
     gtk_tooltips_set_tip(Tips,MessageBoxPositionNone,_("Let the Window Manager "
@@ -342,7 +345,7 @@ void Open_OptionsWindow (void)
     MessageBoxPositionCenterOnParent = gtk_radio_button_new_with_label(
         gtk_radio_button_get_group(GTK_RADIO_BUTTON(MessageBoxPositionNone)),
         _("Center of the main window"));
-    gtk_box_pack_start(GTK_BOX(vbox),MessageBoxPositionCenterOnParent,FALSE,FALSE,0);
+    gtk_table_attach(GTK_TABLE(Table),MessageBoxPositionCenterOnParent,1,2,0,1,GTK_FILL,GTK_FILL,0,0);
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(MessageBoxPositionCenterOnParent),
         MESSAGE_BOX_POSITION_CENTER_ON_PARENT);
     gtk_tooltips_set_tip(Tips,MessageBoxPositionCenterOnParent,_("Windows should "
@@ -351,7 +354,7 @@ void Open_OptionsWindow (void)
     MessageBoxPositionCenter = gtk_radio_button_new_with_label(
         gtk_radio_button_get_group(GTK_RADIO_BUTTON(MessageBoxPositionNone)),
         _("Center of the screen"));
-    gtk_box_pack_start(GTK_BOX(vbox),MessageBoxPositionCenter,FALSE,FALSE,0);
+    gtk_table_attach(GTK_TABLE(Table),MessageBoxPositionCenter,0,1,1,2,GTK_FILL,GTK_FILL,0,0);
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(MessageBoxPositionCenter),
         MESSAGE_BOX_POSITION_CENTER);
     gtk_tooltips_set_tip(Tips,MessageBoxPositionCenter,_("Windows should be placed "
@@ -360,7 +363,7 @@ void Open_OptionsWindow (void)
     MessageBoxPositionMouse = gtk_radio_button_new_with_label(
         gtk_radio_button_get_group(GTK_RADIO_BUTTON(MessageBoxPositionNone)),
         _("Mouse position"));
-    gtk_box_pack_start(GTK_BOX(vbox),MessageBoxPositionMouse,FALSE,FALSE,0);
+    gtk_table_attach(GTK_TABLE(Table),MessageBoxPositionMouse,1,2,1,2,GTK_FILL,GTK_FILL,0,0);
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(MessageBoxPositionMouse),
         MESSAGE_BOX_POSITION_MOUSE);
     gtk_tooltips_set_tip(Tips,MessageBoxPositionMouse,_("Windows should be placed "
@@ -376,7 +379,7 @@ void Open_OptionsWindow (void)
     else
         gtk_list_store_clear(FilePlayerModel);
 
-    hbox = gtk_hbox_new(FALSE,4);
+    hbox = gtk_hbox_new(FALSE,2);
     gtk_container_add(GTK_CONTAINER(Frame),hbox);
     gtk_container_set_border_width(GTK_CONTAINER(hbox), 4);
     Label = gtk_label_new (_("Player to run :"));
@@ -547,7 +550,6 @@ void Open_OptionsWindow (void)
     gtk_box_pack_start(GTK_BOX(vbox),hbox,FALSE,FALSE,0);
 
     NumberTrackFormated = gtk_check_button_new_with_label(_("Write the track field with the following number of digits :"));
-    //gtk_box_pack_start(GTK_BOX(vbox),NumberTrackFormated,FALSE,FALSE,0);
     gtk_box_pack_start(GTK_BOX(hbox),NumberTrackFormated,FALSE,FALSE,0);
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(NumberTrackFormated),NUMBER_TRACK_FORMATED);
     gtk_tooltips_set_tip(Tips,NumberTrackFormated,_("If activated, the track field is written using "
@@ -1011,7 +1013,7 @@ void Open_OptionsWindow (void)
     gtk_container_set_border_width(GTK_CONTAINER(vbox), 4);
 
     // 1rst automatic search server
-    hbox = gtk_hbox_new(FALSE,4);
+    hbox = gtk_hbox_new(FALSE,2);
     gtk_container_add(GTK_CONTAINER(vbox),hbox);
     Label = gtk_label_new(_("Name :"));
     gtk_box_pack_start(GTK_BOX(hbox),Label,FALSE,FALSE,2);
@@ -1048,7 +1050,7 @@ void Open_OptionsWindow (void)
     gtk_entry_set_text(GTK_ENTRY(CddbServerCgiPathAutomaticSearch) ,CDDB_SERVER_CGI_PATH_AUTOMATIC_SEARCH);
 
     // 2sd automatic search server
-    hbox = gtk_hbox_new(FALSE,4);
+    hbox = gtk_hbox_new(FALSE,2);
     gtk_container_add(GTK_CONTAINER(vbox),hbox);
     Label = gtk_label_new(_("Name :"));
     gtk_box_pack_start(GTK_BOX(hbox),Label,FALSE,FALSE,2);
@@ -1080,7 +1082,7 @@ void Open_OptionsWindow (void)
     gtk_container_add(GTK_CONTAINER(Frame),vbox);
     gtk_container_set_border_width(GTK_CONTAINER(vbox), 4);
 
-    hbox = gtk_hbox_new(FALSE,4);
+    hbox = gtk_hbox_new(FALSE,2);
     gtk_container_add(GTK_CONTAINER(vbox),hbox);
     Label = gtk_label_new(_("Name :"));
     gtk_box_pack_start(GTK_BOX(hbox),Label,FALSE,FALSE,2);
@@ -1106,62 +1108,105 @@ void Open_OptionsWindow (void)
     gtk_box_pack_start(GTK_BOX(hbox),CddbServerCgiPathManualSearch,FALSE,FALSE,0);
     gtk_entry_set_text(GTK_ENTRY(CddbServerCgiPathManualSearch) ,CDDB_SERVER_CGI_PATH_MANUAL_SEARCH);
 
+    // Local access for CDDB (Automatic Search)
+    Frame = gtk_frame_new (_("Local CD Data Base"));
+    gtk_box_pack_start(GTK_BOX(VBox),Frame,FALSE,FALSE,0);
+    vbox = gtk_vbox_new(FALSE,2);
+    gtk_container_add(GTK_CONTAINER(Frame),vbox);
+    gtk_container_set_border_width(GTK_CONTAINER(vbox), 4);
+
+    hbox = gtk_hbox_new(FALSE,2);
+    gtk_container_add(GTK_CONTAINER(vbox),hbox);
+    Label = gtk_label_new(_("Path :"));
+    gtk_box_pack_start(GTK_BOX(hbox),Label,FALSE,FALSE,2);
+
+    if (CddbLocalPathModel != NULL)
+        gtk_list_store_clear(CddbLocalPathModel);
+    else
+        CddbLocalPathModel = gtk_list_store_new(MISC_COMBO_COUNT, G_TYPE_STRING);
+
+    CddbLocalPath = gtk_combo_box_entry_new_with_model(GTK_TREE_MODEL(CddbLocalPathModel), MISC_COMBO_TEXT);
+    gtk_box_pack_start(GTK_BOX(hbox),CddbLocalPath,FALSE,FALSE,0);
+    gtk_widget_set_size_request(GTK_WIDGET(CddbLocalPath), 450, -1);
+    gtk_tooltips_set_tip(Tips,GTK_BIN(CddbLocalPath)->child,_("Specify the directory "
+        "where are located the local cd data base. The local cd data base contains the eleven following "
+        "directories 'blues', 'classical', 'country', 'data', 'folk', 'jazz', 'newage', 'reggae', "
+        "'rock', 'soundtrack' and 'misc'."),NULL);
+    g_signal_connect(G_OBJECT(GTK_ENTRY(GTK_BIN(CddbLocalPath)->child)),"activate",G_CALLBACK(CddbLocalPath_Combo_Add_String),NULL);
+    //g_signal_connect(G_OBJECT(GTK_ENTRY(GTK_BIN(CddbLocalPath)->child)),"focus_out_event",G_CALLBACK(CddbLocalPath_Combo_Add_String),NULL);
+
+    // History list
+    Load_Cddb_Local_Path_List(CddbLocalPathModel, MISC_COMBO_TEXT);
+
+    // If default path hasn't been added already, add it now..
+    if (CDDB_LOCAL_PATH)
+    {
+        path_utf8 = filename_to_display(CDDB_LOCAL_PATH);
+        Add_String_To_Combo_List(CddbLocalPathModel, path_utf8);
+        gtk_entry_set_text(GTK_ENTRY(GTK_BIN(CddbLocalPath)->child), path_utf8);
+        g_free(path_utf8);
+    }
+
+    Button = Create_Button_With_Pixmap(BUTTON_BROWSE);
+    gtk_box_pack_start(GTK_BOX(hbox),Button,FALSE,FALSE,0);
+    g_signal_connect_swapped(G_OBJECT(Button),"clicked",
+                             G_CALLBACK(File_Selection_Window_For_Directory),G_OBJECT(GTK_BIN(CddbLocalPath)->child));
+
     // CDDB Proxy Settings
     Frame = gtk_frame_new (_("Proxy Settings"));
     gtk_box_pack_start(GTK_BOX(VBox),Frame,FALSE,FALSE,0);
 
-    Table = gtk_table_new(4,4,FALSE);
+    Table = gtk_table_new(3,5,FALSE);
     gtk_container_add(GTK_CONTAINER(Frame),Table);
     gtk_table_set_row_spacings(GTK_TABLE(Table),2);
     gtk_table_set_col_spacings(GTK_TABLE(Table),4);
     gtk_container_set_border_width(GTK_CONTAINER(Table), 2);
 
     CddbUseProxy = gtk_check_button_new_with_label(_("Use a proxy"));
-    gtk_table_attach(GTK_TABLE(Table),CddbUseProxy,0,4,0,1,GTK_FILL,GTK_FILL,0,0);
+    gtk_table_attach(GTK_TABLE(Table),CddbUseProxy,0,5,0,1,GTK_FILL,GTK_FILL,0,0);
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(CddbUseProxy),CDDB_USE_PROXY);
     gtk_tooltips_set_tip(Tips,CddbUseProxy,_("Set active the settings of the proxy server."),NULL);
 
-    Label = gtk_label_new(_("Host Name :"));
+    Label = gtk_label_new("     ");
     gtk_table_attach(GTK_TABLE(Table),Label,0,1,1,2,GTK_FILL,GTK_FILL,0,0);
+
+    Label = gtk_label_new(_("Host Name :"));
+    gtk_table_attach(GTK_TABLE(Table),Label,1,2,1,2,GTK_FILL,GTK_FILL,0,0);
     gtk_misc_set_alignment(GTK_MISC(Label),1,0.5);
     CddbProxyName = gtk_entry_new();
-    gtk_table_attach(GTK_TABLE(Table),CddbProxyName,1,2,1,2,GTK_FILL,GTK_FILL,0,0);
+    gtk_table_attach(GTK_TABLE(Table),CddbProxyName,2,3,1,2,GTK_FILL,GTK_FILL,0,0);
     if (CDDB_PROXY_NAME)
         gtk_entry_set_text(GTK_ENTRY(CddbProxyName),CDDB_PROXY_NAME);
     gtk_tooltips_set_tip(Tips,CddbProxyName,_("Name of the proxy server."),NULL);
     Label = gtk_label_new (_("Port :"));
-    gtk_table_attach(GTK_TABLE(Table),Label,2,3,1,2,GTK_FILL,GTK_FILL,0,0);
+    gtk_table_attach(GTK_TABLE(Table),Label,3,4,1,2,GTK_FILL,GTK_FILL,0,0);
     gtk_misc_set_alignment(GTK_MISC(Label),1,0.5);
     CddbProxyPort = gtk_entry_new();
     gtk_widget_set_size_request(GTK_WIDGET(CddbProxyPort), 45, -1);
     gtk_entry_set_max_length(GTK_ENTRY(CddbProxyPort),5);
-    gtk_table_attach(GTK_TABLE(Table),CddbProxyPort,3,4,1,2,GTK_FILL,GTK_FILL,0,0);
+    gtk_table_attach(GTK_TABLE(Table),CddbProxyPort,4,5,1,2,GTK_FILL,GTK_FILL,0,0);
     gtk_tooltips_set_tip(Tips,CddbProxyPort,_("Port of the proxy server."),NULL);
     sprintf(temp,"%i",CDDB_PROXY_PORT);
     gtk_entry_set_text(GTK_ENTRY(CddbProxyPort),temp);
     g_signal_connect(G_OBJECT(CddbProxyPort),"insert_text",G_CALLBACK(Insert_Only_Digit),NULL);
     g_signal_connect(G_OBJECT(CddbUseProxy),"toggled",G_CALLBACK(Cddb_Use_Proxy_Toggled),NULL);
     Label = gtk_label_new(_("User Name :"));
-    gtk_table_attach(GTK_TABLE(Table),Label,0,1,2,3,GTK_FILL,GTK_FILL,0,0);
+    gtk_table_attach(GTK_TABLE(Table),Label,1,2,2,3,GTK_FILL,GTK_FILL,0,0);
     gtk_misc_set_alignment(GTK_MISC(Label),1,0.5);
     CddbProxyUserName = gtk_entry_new();
     if (CDDB_PROXY_USER_NAME)
         gtk_entry_set_text(GTK_ENTRY(CddbProxyUserName),CDDB_PROXY_USER_NAME);
-    gtk_table_attach(GTK_TABLE(Table),CddbProxyUserName,1,2,2,3,GTK_FILL,GTK_FILL,0,0);
+    gtk_table_attach(GTK_TABLE(Table),CddbProxyUserName,2,3,2,3,GTK_FILL,GTK_FILL,0,0);
     gtk_tooltips_set_tip(Tips,CddbProxyUserName,_("Name of user for the the proxy server."),NULL);
-//    Label = gtk_label_new(_("(Not available!)"));
-//    gtk_table_attach(GTK_TABLE(Table),Label,2,5,2,3,GTK_FILL,GTK_FILL,0,0);
     Label = gtk_label_new(_("User Password :"));
-    gtk_table_attach(GTK_TABLE(Table),Label,0,1,3,4,GTK_FILL,GTK_FILL,0,0);
+    gtk_table_attach(GTK_TABLE(Table),Label,3,4,2,3,GTK_FILL,GTK_FILL,0,0);
     gtk_misc_set_alignment(GTK_MISC(Label),1,0.5);
     CddbProxyUserPassword = gtk_entry_new();
     if (CDDB_PROXY_USER_PASSWORD)
         gtk_entry_set_text(GTK_ENTRY(CddbProxyUserPassword),CDDB_PROXY_USER_PASSWORD);
-    gtk_table_attach(GTK_TABLE(Table),CddbProxyUserPassword,1,2,3,4,GTK_FILL,GTK_FILL,0,0);
+    gtk_table_attach(GTK_TABLE(Table),CddbProxyUserPassword,4,5,2,3,GTK_FILL,GTK_FILL,0,0);
     gtk_entry_set_visibility(GTK_ENTRY(CddbProxyUserPassword),FALSE);
     gtk_tooltips_set_tip(Tips,CddbProxyUserPassword,_("Password of user for the the proxy server."),NULL);
-//    Label = gtk_label_new(_("(Not available!)"));
-//    gtk_table_attach(GTK_TABLE(Table),Label,2,5,3,4,GTK_FILL,GTK_FILL,0,0);
     Cddb_Use_Proxy_Toggled();
 
 
@@ -1351,6 +1396,7 @@ void OptionsWindow_Apply_Button(void)
     Add_String_To_Combo_List(DefaultPathModel,    (gchar*) gtk_entry_get_text(GTK_ENTRY(GTK_BIN(DefaultPathToMp3)->child)));
     Add_String_To_Combo_List(FilePlayerModel,     (gchar*) gtk_entry_get_text(GTK_ENTRY(GTK_BIN(FilePlayerCombo)->child)));
     Add_String_To_Combo_List(DefaultCommentModel, (gchar*) gtk_entry_get_text(GTK_ENTRY(GTK_BIN(DefaultComment)->child)));
+    Add_String_To_Combo_List(CddbLocalPathModel,  (gchar*) gtk_entry_get_text(GTK_ENTRY(GTK_BIN(CddbLocalPath)->child)));
 #endif
 
     Apply_Changes_Of_Preferences_Window();
@@ -1369,6 +1415,7 @@ void OptionsWindow_Save_Button(void)
     Add_String_To_Combo_List(DefaultPathModel,      (gchar*) gtk_entry_get_text(GTK_ENTRY(GTK_BIN(DefaultPathToMp3)->child)));
     Add_String_To_Combo_List(FilePlayerModel,       (gchar*) gtk_entry_get_text(GTK_ENTRY(GTK_BIN(FilePlayerCombo)->child)));
     Add_String_To_Combo_List(DefaultCommentModel,   (gchar*) gtk_entry_get_text(GTK_ENTRY(GTK_BIN(DefaultComment)->child)));
+    Add_String_To_Combo_List(CddbLocalPathModel,    (gchar*) gtk_entry_get_text(GTK_ENTRY(GTK_BIN(CddbLocalPath)->child)));
 #endif
 
     Save_Changes_Of_Preferences_Window();
@@ -1390,9 +1437,10 @@ void OptionsWindow_Quit(void)
     if (OptionsWindow)
     {
         /* Save combobox history lists before exit */
-        Save_Default_Path_To_MP3_List(DefaultPathModel, MISC_COMBO_TEXT);
+        Save_Default_Path_To_MP3_List     (DefaultPathModel, MISC_COMBO_TEXT);
         Save_Default_Tag_Comment_Text_List(DefaultCommentModel, MISC_COMBO_TEXT);
-        Save_Audio_File_Player_List(FilePlayerModel, MISC_COMBO_TEXT);
+        Save_Audio_File_Player_List       (FilePlayerModel, MISC_COMBO_TEXT);
+        Save_Cddb_Local_Path_List         (CddbLocalPathModel, MISC_COMBO_TEXT);
 
         OptionsWindow_Apply_Changes();
 
@@ -1626,3 +1674,13 @@ void DefaultPathToMp3_Combo_Add_String (void)
     path = gtk_entry_get_text(GTK_ENTRY(GTK_BIN(DefaultPathToMp3)->child));
     Add_String_To_Combo_List(GTK_LIST_STORE(DefaultPathModel), (gchar *)path);
 }
+
+void CddbLocalPath_Combo_Add_String (void)
+{
+    const gchar *path;
+
+    path = gtk_entry_get_text(GTK_ENTRY(GTK_BIN(CddbLocalPath)->child));
+    Add_String_To_Combo_List(GTK_LIST_STORE(CddbLocalPath), (gchar *)path);
+}
+
+
